from hatak.plugin import Plugin
from haplugin.jinja2 import Jinja2Plugin


class HamlPlugin(Plugin):

    def before_config(self):
        extensions = self.settings.get('jinja2.extensions', [])
        extensions.append('hamlish_jinja.HamlishExtension')
        self.settings['jinja2.extensions'] = extensions

    def add_to_registry(self):
        self.config.add_jinja2_renderer('.haml')

    def validate_plugin(self):
        self.app._validate_dependency_plugin(Jinja2Plugin)



# -*- encoding: utf-8 -*-
from setuptools import setup, find_packages

install_requires = [
    'hatak>=0.2',
    'Hatak_Jinja2',
    'hamlish_jinja',
]

if __name__ == '__main__':
    setup(
        name='Hatak_Haml',
        version='0.1',
        description='Haml plugin for Hatak.',
        license='Apache License 2.0',
        packages=find_packages('src'),
        package_dir={'': 'src'},
        namespace_packages=['haplugin'],
        install_requires=install_requires,
        include_package_data=True,
        zip_safe=False,
    )
